@@ -369,9 +369,10 @@ load_configuration (CLLauncherAppletData *data)
 		application_list = g_slist_append (application_list, g_strdup (FLASHLIGHT_APPLET_DESKTOP_FILE));
 	}
 
+	selector = hildon_picker_button_get_selector (HILDON_PICKER_BUTTON (data->application_list));
+	tree_model = hildon_touch_selector_get_model (selector, SELECTOR_COLUMN_NAME);
+	hildon_touch_selector_unselect_all(selector, SELECTOR_COLUMN_NAME);
 	for (entry = application_list; entry; entry = entry->next) {
-		selector = hildon_picker_button_get_selector (HILDON_PICKER_BUTTON (data->application_list));
-		tree_model = hildon_touch_selector_get_model (selector, SELECTOR_COLUMN_NAME);
 		for (iter_valid = gtk_tree_model_get_iter_first (tree_model, &iter); iter_valid;
 		     iter_valid = gtk_tree_model_iter_next (tree_model, &iter)) {
 			const gchar *filename;
